@@ -39,7 +39,7 @@ function(var,infile,outfile){
    v_missing_value = "undefined"
 
    info = "Created with the CM SAF R toolbox." 
-   var_prec="double"
+   var_prec="float"
 
    att_list <- c("standard_name","long_name","units","_FillValue","missing_value","calendar")
    v_att_list <- c("v_standard_name","v_long_name","v_units","v__FillValue","v_missing_value","v_calendar")
@@ -119,8 +119,8 @@ function(var,infile,outfile){
   cat("create netcdf", "\n")
 
     if (length(time1)==1){
-      dummy <- array(NA,dim=c(dim(target)[1],dim(target)[2],1))
-      dummy[,,1] <- target
+      dummy <- array(NA,dim=c(1,1,1))
+      dummy[1,1,1] <- target
       target <- dummy
     }
 
