@@ -39,7 +39,7 @@ function(var,infile,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90){
    v_missing_value = "undefined"
 
    info = "Created with the CM SAF R toolbox." 
-   var_prec="double"
+   var_prec="float"
 
    att_list <- c("standard_name","long_name","units","_FillValue","missing_value","calendar")
    v_att_list <- c("v_standard_name","v_long_name","v_units","v__FillValue","v_missing_value","v_calendar")
@@ -78,6 +78,12 @@ function(var,infile,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90){
   # get information about variables
 	
   varnames <- names(id$var)
+  
+    # set variable precision 
+    varind   <- which(varnames==var)
+    varprec  <- NULL
+    varprec  <- id$var[[varind]]$prec
+    if (!is.null(varprec))(var_prec <- varprec)
 
    if (var %in% varnames){
     for (i in 1:6){
